# ProjectDef

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**constraints** | [**list[ProjectDefConstraints]**](ProjectDefConstraints.md) |  |
**requirements** | **object** | Requirements stating direct dependencies of the project, the format is compatible with Pipenv  |
**requirements_locked** | **object** | A lock file stating all the dependencies pinned to a specific version togher with an explicit Python package index configuration  |
**runtime_environment** | [**RuntimeEnvironment**](RuntimeEnvironment.md) |  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

